@@ -106,10 +106,11 @@ class BaseTestCase(testtools.TestCase):
 
     def _await_instance_event(
             self, instance_uuid, operation, message=None, after=None):
-        # Wait up to two minutes for the instance to be created.
+        # Wait up to 5 minutes for the instance to be created. On a slow
+        # morning it can take over 2 minutes to download a Ubuntu image.
         start_time = time.time()
         final = False
-        while time.time() - start_time < 120:
+        while time.time() - start_time < 300:
             i = self.system_client.get_instance(instance_uuid)
             if i['state'] in ['created', 'error']:
                 final = True
@@ -246,17 +247,6 @@ class LoggingSocket(object):
     def __init__(self, host, port):
         self.s = telnetlib.Telnet(host, port, 30)
 
-    def await_login_prompt(self):
-        start_time = time.time()
-        while True:
-            for line in self.recv().split('\n'):
-                if line.rstrip('\r\n ').endswith(' login:'):
-                    return
-
-            time.sleep(0.5)
-            if time.time() - start_time > 120.0:
-                return
-
     def ensure_fresh(self):
         for d in [self.ctrlc, self.ctrlc, '\nexit\n', 'cirros\n', 'gocubsgo\n']:
             self.send(d)
@@ -264,13 +254,13 @@ class LoggingSocket(object):
             self.recv()
 
     def send(self, data):
-        # print('>> %s' % data.replace('\n', '\\n').replace('\r', '\\r'))
+        print('>> %s' % data.replace('\n', '\\n').replace('\r', '\\r'))
         self.s.write(data.encode('ascii'))
 
     def recv(self):
         data = self.s.read_eager().decode('ascii')
-        # for line in data.split('\n'):
-        #    print('<< %s' % line.replace('\n', '\\n').replace('\r', '\\r'))
+        for line in data.split('\n'):
+            print('<< %s' % line.replace('\n', '\\n').replace('\r', '\\r'))
         return data
 
     def execute(self, cmd):
@@ -278,6 +268,12 @@ class LoggingSocket(object):
         self.send(cmd + '\n')
         time.sleep(5)
         d = ''
+
+        reads = 0
         while not d.endswith('\n$ '):
             d += self.recv()
+            reads += 1
+
+            if reads > 10:
+                break
         return d
