@@ -5,7 +5,7 @@ import requests
 import setproctitle
 import time
 
-from shakenfist import config
+from shakenfist.config import config
 from shakenfist.daemons import daemon
 from shakenfist import db
 from shakenfist import exceptions
@@ -81,7 +81,7 @@ def handle(jobname, workitem):
             elif isinstance(task, StartInstanceTask):
                 instance_start(instance_uuid, task.network())
                 db.update_instance_state(instance_uuid, 'created')
-                db.enqueue('%s-metrics' % config.parsed.get('NODE_NAME'), {})
+                db.enqueue('%s-metrics' % config.NODE_NAME, {})
 
             elif isinstance(task, DeleteInstanceTask):
                 try:
@@ -98,8 +98,7 @@ def handle(jobname, workitem):
                     if task.error_msg():
                         db.update_instance_error_message(
                             instance_uuid, task.error_msg())
-                    db.enqueue('%s-metrics' %
-                               config.parsed.get('NODE_NAME'), {})
+                    db.enqueue('%s-metrics' % config.NODE_NAME, {})
                 except Exception as e:
                     util.ignore_exception(daemon.process_name('queues'), e)
 
@@ -122,7 +121,7 @@ def handle(jobname, workitem):
                                       'failed queue task: %s' % e)
 
     finally:
-        db.resolve(config.parsed.get('NODE_NAME'), jobname)
+        db.resolve(config.NODE_NAME, jobname)
         if instance_uuid:
             db.add_event('instance', instance_uuid, 'tasks complete',
                          'dequeued', None, 'Work item %s' % jobname)
@@ -138,9 +137,8 @@ def image_fetch(url, instance_uuid):
         # TODO(andy): Wait up to 15 mins for another queue process to download
         # the required image. This will be changed to queue on a
         # "waiting_image_fetch" queue but this works now.
-        with db.get_lock('image', config.parsed.get('NODE_NAME'),
-                         Image.calc_unique_ref(url), timeout=15*60,
-                         op='Image fetch') as lock:
+        with db.get_lock('image', config.NODE_NAME, Image.calc_unique_ref(url),
+                         timeout=15*60, op='Image fetch') as lock:
             img = Image.from_url(url)
             img.get([lock], instance)
             db.add_event('image', url, 'fetch', None, None, 'success')
@@ -170,8 +168,7 @@ def instance_preflight(instance_uuid, network):
     instance = virt.from_db(instance_uuid)
 
     try:
-        s.place_instance(
-            instance, network, candidates=[config.parsed.get('NODE_NAME')])
+        s.place_instance(instance, network, candidates=[config.NODE_NAME])
         return None
 
     except exceptions.LowResourceException as e:
@@ -189,7 +186,7 @@ def instance_preflight(instance_uuid, network):
         else:
             candidates = []
             for node in s.metrics.keys():
-                if node != config.parsed.get('NODE_NAME'):
+                if node != config.NODE_NAME:
                     candidates.append(node)
 
         candidates = s.place_instance(instance, network,
@@ -206,14 +203,13 @@ def instance_preflight(instance_uuid, network):
 
 
 def instance_start(instance_uuid, network):
+    log = LOG.withField('instance', instance_uuid)
+
     with db.get_lock(
             'instance', None, instance_uuid, ttl=900, timeout=120,
             op='Instance start') as lock:
         instance = virt.from_db(instance_uuid)
 
-        # Allocate console and VDI ports
-        instance.allocate_instance_ports()
-
         # Collect the networks
         nets = {}
         for netdesc in network:
@@ -229,9 +225,19 @@ def instance_start(instance_uuid, network):
         with util.RecordedOperation('ensure networks exist', instance):
             for network_uuid in nets:
                 n = nets[network_uuid]
-                n.create()
-                n.ensure_mesh()
-                n.update_dhcp()
+                try:
+                    n.create()
+                    n.ensure_mesh()
+                    n.update_dhcp()
+                except exceptions.DeadNetwork as e:
+                    log.withField('network', n).warning(
+                        'Instance tried to use dead network')
+                    db.enqueue_instance_error(
+                        instance_uuid, 'tried to use dead network: %s' % e)
+                    return
+
+        # Allocate console and VDI ports
+        instance.allocate_instance_ports()
 
         # Now we can start the instance
         libvirt = util.get_libvirt()
@@ -266,8 +272,7 @@ def instance_delete(instance_uuid):
 
         # Create list of networks used by all other instances
         host_networks = []
-        for inst in list(
-                db.get_instances(only_node=config.parsed.get('NODE_NAME'))):
+        for inst in list(db.get_instances(only_node=config.NODE_NAME)):
             if not inst['uuid'] == instance_uuid:
                 for iface in db.get_instance_interfaces(inst['uuid']):
                     if not iface['network_uuid'] in host_networks:
@@ -309,8 +314,7 @@ class Monitor(daemon.Daemon):
                         workers.remove(w)
 
                 if len(workers) < present_cpus / 2:
-                    jobname, workitem = db.dequeue(
-                        config.parsed.get('NODE_NAME'))
+                    jobname, workitem = db.dequeue(config.NODE_NAME)
                 else:
                     workitem = None
 
