@@ -6,8 +6,7 @@ import socket
 import time
 import uuid
 
-
-from shakenfist import config
+from shakenfist.config import config
 from shakenfist import etcd
 from shakenfist import exceptions
 from shakenfist import ipmanager
@@ -15,6 +14,7 @@ from shakenfist import logutil
 from shakenfist import util
 from shakenfist.tasks import DeleteInstanceTask, ErrorInstanceTask
 
+
 # TODO(andy): Change back to 5 once network bugs fixed
 ETCD_ATTEMPT_TIMEOUT = 15
 
@@ -24,11 +24,10 @@ LOG, _ = logutil.setup(__name__)
 
 def see_this_node():
     etcd.put(
-        'node', None,
-        config.parsed.get('NODE_NAME'),
+        'node', None, config.NODE_NAME,
         {
-            'fqdn': config.parsed.get('NODE_NAME'),
-            'ip': config.parsed.get('NODE_IP'),
+            'fqdn': config.NODE_NAME,
+            'ip': config.NODE_IP,
             'lastseen': time.time(),
             'version': util.get_version()
         },
@@ -85,7 +84,7 @@ def get_nodes():
 
 def get_network_node():
     for n in get_nodes():
-        if n['ip'] == config.parsed.get('NETWORK_NODE_IP'):
+        if n['ip'] == config.NETWORK_NODE_IP:
             return n
 
 
@@ -247,7 +246,7 @@ def create_instance(instance_uuid, name, cpus, memory_mb, disk_spec, ssh_key,
         'memory': memory_mb,
         'disk_spec': disk_spec,
         'ssh_key': ssh_key,
-        'node': config.parsed.get('NODE_NAME'),
+        'node': config.NODE_NAME,
         'console_port': 0,
         'vdi_port': 0,
         'user_data': user_data,
@@ -286,6 +285,10 @@ def instance_enforced_deletes_increment(instance_uuid):
 
 def update_instance_state(instance_uuid, state):
     i = get_instance(instance_uuid)
+    if not i:
+        LOG.withField('instance_uuid', instance_uuid).error(
+            'update_instance_state() Instance does not exist')
+        return
 
     # We don't write unchanged things to the database
     if i.get('state') == state:
@@ -441,7 +444,7 @@ def add_event(object_type, object_uuid, operation, phase, duration, message):
     LOG.withFields(
         {
             object_type: object_uuid,
-            'fqdn': config.parsed.get('NODE_NAME'),
+            'fqdn': config.NODE_NAME,
             'operation': operation,
             'phase': phase,
             'duration': duration,
@@ -453,7 +456,7 @@ def add_event(object_type, object_uuid, operation, phase, duration, message):
             'timestamp': t,
             'object_type': object_type,
             'object_uuid': object_uuid,
-            'fqdn': config.parsed.get('NODE_NAME'),
+            'fqdn': config.NODE_NAME,
             'operation': operation,
             'phase': phase,
             'duration': duration,
@@ -468,11 +471,10 @@ def get_events(object_type, object_uuid):
 
 
 def update_metrics_bulk(metrics):
-    node = config.parsed.get('NODE_NAME')
     etcd.put(
-        'metrics', node, None,
+        'metrics', config.NODE_NAME, None,
         {
-            'fqdn': node,
+            'fqdn': config.NODE_NAME,
             'timestamp': time.time(),
             'metrics': metrics
         },
@@ -487,7 +489,7 @@ def get_metrics(fqdn):
 
 
 def allocate_console_port(instance_uuid):
-    node = config.parsed.get('NODE_NAME')
+    node = config.NODE_NAME
     consumed = {value['port'] for value in etcd.get_all('console', node)}
     while True:
         port = random.randint(30000, 50000)
@@ -516,7 +518,7 @@ def allocate_console_port(instance_uuid):
 
 
 def free_console_port(port):
-    etcd.delete('console', config.parsed.get('NODE_NAME'), port)
+    etcd.delete('console', config.NODE_NAME, port)
 
 
 def list_namespaces():
@@ -560,8 +562,7 @@ def enqueue(queuename, workitem):
 
 
 def enqueue_instance_delete(instance_uuid):
-    enqueue_instance_delete_remote(config.parsed.get('NODE_NAME'),
-                                   instance_uuid)
+    enqueue_instance_delete_remote(config.NODE_NAME, instance_uuid)
 
 
 def enqueue_instance_delete_remote(node, instance_uuid):
@@ -573,7 +574,7 @@ def enqueue_instance_delete_remote(node, instance_uuid):
 
 
 def enqueue_instance_error(instance_uuid, error_msg):
-    enqueue(config.parsed.get('NODE_NAME'), {
+    enqueue(config.NODE_NAME, {
         'tasks': [
             ErrorInstanceTask(instance_uuid, error_msg)
         ],
