@@ -4,10 +4,9 @@ import json
 import mock
 
 
-from shakenfist import config
+from shakenfist.config import config, SFConfigBase
 from shakenfist.external_api import app as external_api
 from shakenfist import ipmanager
-from shakenfist import net
 from shakenfist.tests import test_shakenfist
 
 
@@ -22,7 +21,7 @@ class FakeResponse(object):
 
 class FakeScheduler(object):
     def place_instance(self, *args, **kwargs):
-        return config.parsed.get('NODE_NAME')
+        return config.NODE_NAME
 
 
 class FakeInstance(object):
@@ -201,6 +200,7 @@ class ExternalApiTestCase(test_shakenfist.ShakenFistTestCase):
 
         resp = self.client.post(
             '/auth', data=json.dumps({'namespace': 'system', 'key': 'foo'}))
+        print(resp.get_json())
         self.assertEqual(200, resp.status_code)
         self.auth_header = 'Bearer %s' % resp.get_json()['access_token']
 
@@ -679,17 +679,13 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
         self.mock_virt_from_db = self.virt_from_db.start()
         self.addCleanup(self.virt_from_db.stop)
 
-        def fake_config_instance(key):
-            fc = {
-                'API_ASYNC_WAIT': 1,
-                'LOG_METHOD_TRACE': 1,
-            }
-            if key in fc:
-                return fc[key]
-            raise Exception('fake_config_instance() Unknown config key')
+        class FakeConfig(SFConfigBase):
+            API_ASYNC_WAIT: int = 1
+            LOG_METHOD_TRACE: int = 1
 
-        self.config = mock.patch('shakenfist.config.parsed.get',
-                                 fake_config_instance)
+        fake_config = FakeConfig()
+
+        self.config = mock.patch('shakenfist.config.config', fake_config)
         self.mock_config = self.config.start()
 
         self.addCleanup(self.config.stop)
@@ -949,25 +945,27 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
     def setUp(self):
         super(ExternalApiNetworkTestCase, self).setUp()
 
-        def fake_config_network(key):
-            fc = {
-                'NODE_NAME': 'seriously',
-                'NODE_IP': '127.0.0.1',
-                'NETWORK_NODE_IP': '127.0.0.1',
-                'LOG_METHOD_TRACE': 1,
-                'NODE_EGRESS_NIC': 'eth0'
-            }
-            if key in fc:
-                return fc[key]
-            raise Exception('fake_config_network() Unknown config key')
+        class FakeConfig(SFConfigBase):
+            NODE_NAME: str = 'seriously'
+            NODE_IP: str = '127.0.0.1'
+            NETWORK_NODE_IP = '127.0.0.1'
+            LOG_METHOD_TRACE: int = 1
+            NODE_EGRESS_NIC: str = 'eth0'
 
-        self.config = mock.patch('shakenfist.config.parsed.get',
+        fake_config_network = FakeConfig()
+        self.config = mock.patch('shakenfist.config.config',
                                  fake_config_network)
         self.mock_config = self.config.start()
-        # Without this cleanup, other test classes will have 'config.parsed.get'
-        # mocked during parallel testing by stestr.
+        # Without this cleanup, other test classes will have
+        # 'shakenfist.config.config.get' mocked during parallel testing
+        # by stestr.
         self.addCleanup(self.config.stop)
 
+    @mock.patch('shakenfist.db.get_network',
+                return_value={
+                    'uuid': '30f6da44-look-i-am-uuid',
+                    'state': 'created',
+                    })
     @mock.patch('shakenfist.db.get_networks',
                 return_value=[{
                     'floating_gateway': '10.10.0.150',
@@ -991,12 +989,8 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
                                  mock_remove_dhcp,
                                  mock_get_ipmanager,
                                  mock_db_get_network_interfaces,
-                                 mock_db_get_networks):
-
-        mock_network = mock.patch('shakenfist.net.from_db',
-                                  return_value=net.Network({'uuid': 'foo'}))
-        mock_network.start()
-        self.addCleanup(mock_network.stop)
+                                 mock_db_get_networks,
+                                 mock_db_get_network):
 
         resp = self.client.delete('/networks',
                                   headers={'Authorization': self.auth_header},
@@ -1008,8 +1002,6 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
                          resp.get_json())
         self.assertEqual(200, resp.status_code)
 
-        mock_network.stop()
-
     @mock.patch('shakenfist.db.get_networks',
                 return_value=[{
                     'floating_gateway': '10.10.0.150',
